import { MouseEvent } from 'react';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { mapModelIdSelector, mapOpenedMapsSelector } from '@/redux/map/map.selectors';
import { closeMap, closeMapAndSetMainMapActive, setActiveMap } from '@/redux/map/map.slice';
import { OppenedMap } from '@/redux/map/map.types';
import { Button } from '@/shared/Button';
import { Icon } from '@/shared/Icon';
import { MAIN_MAP } from '@/redux/map/map.constants';
import { twMerge } from 'tailwind-merge';

export const MapNavigation = (): JSX.Element => {
  const dispatch = useAppDispatch();
  const openedMaps = useAppSelector(mapOpenedMapsSelector);
  const currentModelId = useAppSelector(mapModelIdSelector);

  const isActive = (modelId: number): boolean => currentModelId === modelId;
  const isNotMainMap = (modelName: string): boolean => modelName !== MAIN_MAP;

  const onCloseSubmap = (event: MouseEvent<HTMLDivElement>, map: OppenedMap): void => {
    event.stopPropagation();
    if (isActive(map.modelId)) {
      dispatch(closeMapAndSetMainMapActive({ modelId: map.modelId }));
    } else {
      dispatch(closeMap({ modelId: map.modelId }));
    }
  };

  const onSubmapTabClick = (map: OppenedMap): void => {
    dispatch(setActiveMap(map));
  };

  return (
    <div className="flex h-10 w-full flex-row flex-nowrap justify-start overflow-y-auto bg-white-pearl shadow-map-navigation-bar">
      {openedMaps.map(map => (
        <Button
          key={map.modelId}
          className={twMerge(
            'h-10 whitespace-nowrap	',
            isActive(map.modelId) ? 'bg-[#EBF4FF]' : 'font-normal',
          )}
          variantStyles={isActive(map.modelId) ? 'secondary' : 'ghost'}
          onClick={(): void => onSubmapTabClick(map)}
        >
          {map.modelName}
          {isNotMainMap(map.modelName) && (
            // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
            <div onClick={(event): void => onCloseSubmap(event, map)} data-testid="close-icon">
              <Icon name="close" className="ml-3 h-5 w-5 fill-font-400" />
            </div>
          )}
        </Button>
      ))}
    </div>
  );
};
