import { StoreType } from '@/redux/store';
import { Accordion } from '@/shared/Accordion';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { act, render, screen } from '@testing-library/react';
import { drawerSearchStepOneFixture } from '@/redux/drawer/drawerFixture';
import { DrugsAccordion } from './DrugsAccordion.component';

const SECOND_STEP = 2;

const renderComponent = (initialStoreState: InitialStoreState = {}): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <Accordion>
          <DrugsAccordion />
        </Accordion>
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe.skip('DrugsAccordion - component', () => {
  it('should display drugs number after succesfull drug search', () => {
    renderComponent({
      //  drugs: { data: drugsFixture, loading: 'succeeded', error: { name: '', message: '' } },
    });
    //   expect(screen.getByText('Drugs (4)')).toBeInTheDocument();
  });
  it('should display loading indicator while waiting for drug search response', () => {
    renderComponent({
      drugs: { data: [], loading: 'pending', error: { name: '', message: '' } },
    });
    expect(screen.getByText('Drugs (Loading...)')).toBeInTheDocument();
  });
  it('should navigate user to chemical results list after clicking button', async () => {
    const { store } = renderComponent({
      // drugs: {
      //   data: drugsFixture,
      //   loading: 'succeeded',
      //   error: { name: '', message: '' },
      // },
      drawer: drawerSearchStepOneFixture,
    });

    const navigationButton = screen.getByTestId('accordion-item-button');
    await act(() => {
      navigationButton.click();
    });

    const {
      drawer: {
        searchDrawerState: { stepType, selectedValue, currentStep },
      },
    } = store.getState();

    expect(stepType).toBe('drugs');
    expect(selectedValue).toBe(undefined);
    expect(currentStep).toBe(SECOND_STEP);
  });
  it('should disable navigation button when there is no drugs', async () => {
    renderComponent({
      drugs: { data: [], loading: 'succeeded', error: { name: '', message: '' } },
      drawer: drawerSearchStepOneFixture,
    });

    const navigationButton = screen.getByTestId('accordion-item-button');
    expect(navigationButton).toBeDisabled();
  });
  it('should disable navigation button when waiting for api response', async () => {
    renderComponent({
      drugs: { data: [], loading: 'pending', error: { name: '', message: '' } },
      drawer: drawerSearchStepOneFixture,
    });

    const navigationButton = screen.getByTestId('accordion-item-button');
    expect(navigationButton).toBeDisabled();
  });
});
