/* eslint-disable no-magic-numbers */
import { drugsFixture } from '@/models/fixtures/drugFixtures';
import { StoreType } from '@/redux/store';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { render, screen } from '@testing-library/react';
import { AccordionsDetails } from './AccordionsDetails.component';

const PINS_LIST = drugsFixture.map(drug => ({
  id: drug.id,
  name: drug.name,
  data: drug,
}));

const renderComponent = (initialStoreState: InitialStoreState = {}): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <AccordionsDetails pinsList={PINS_LIST} />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('AccordionsDetails - component', () => {
  it('should display name of drug', () => {
    renderComponent();

    const drugName = drugsFixture[0].name;

    expect(screen.getByText(drugName, { exact: false })).toBeInTheDocument();
  });
  it.skip('should display description of drug', () => {
    renderComponent();

    const drugDescription = drugsFixture[0].description;

    expect(screen.getByText(drugDescription || '', { exact: false })).toBeInTheDocument();
  });
  it('should display synonyms of drug', () => {
    renderComponent();

    const firstDrugSynonym = drugsFixture[0].synonyms[0];
    const secondDrugSynonym = drugsFixture[0].synonyms[1];

    expect(screen.getByText(firstDrugSynonym, { exact: false })).toBeInTheDocument();
    expect(screen.getByText(secondDrugSynonym, { exact: false })).toBeInTheDocument();
  });
  it('should display additional info about drug', () => {
    renderComponent();

    const drugAdditionalInfo = drugsFixture[0].bloodBrainBarrier;

    expect(screen.getByText(drugAdditionalInfo, { exact: false })).toBeInTheDocument();
  });
});
