import mapReducer from '@/redux/map/map.slice';
import { MapState } from '@/redux/map/map.types';
import { ToolkitStoreWithSingleSlice } from '@/utils/createStoreInstanceUsingSliceReducer';
import { getReduxWrapperUsingSliceReducer } from '@/utils/testing/getReduxWrapperUsingSliceReducer';
import { render, screen } from '@testing-library/react';
import { MapViewer } from './MapViewer.component';
import { MAP_VIEWER_ROLE } from './MapViewer.constants';

const renderComponent = (): { store: ToolkitStoreWithSingleSlice<MapState> } => {
  const { Wrapper, store } = getReduxWrapperUsingSliceReducer('map', mapReducer);

  return (
    render(
      <Wrapper>
        <MapViewer />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('MapViewer - component', () => {
  it('should render component container', () => {
    renderComponent();

    expect(screen.getByRole(MAP_VIEWER_ROLE)).toBeInTheDocument();
  });

  it('should render openlayers map inside the component', () => {
    renderComponent();

    const FIRST_NODE = 0;

    expect(screen.getByRole(MAP_VIEWER_ROLE).childNodes[FIRST_NODE]).toHaveClass('ol-viewport');
  });
});
