/* eslint-disable no-magic-numbers */
import { OPTIONS } from '@/constants/map';
import { currentBackgroundImagePathSelector } from '@/redux/backgrounds/background.selectors';
import { mapDataSizeSelector } from '@/redux/map/map.selectors';
import { projectDataSelector } from '@/redux/project/project.selectors';
import TileLayer from 'ol/layer/Tile';
import { XYZ } from 'ol/source';
import { useEffect, useMemo } from 'react';
import { useSelector } from 'react-redux';
import { MapConfig, MapInstance } from '../../MapViewer.types';
import { getMapTileUrl } from './getMapTileUrl';

interface UseOlMapLayersInput {
  mapInstance: MapInstance;
}

export const useOlMapLayers = ({ mapInstance }: UseOlMapLayersInput): MapConfig['layers'] => {
  const mapSize = useSelector(mapDataSizeSelector);
  const currentBackgroundImagePath = useSelector(currentBackgroundImagePathSelector);
  const project = useSelector(projectDataSelector);

  const sourceUrl = useMemo(
    () => getMapTileUrl({ projectDirectory: project?.directory, currentBackgroundImagePath }),
    [project?.directory, currentBackgroundImagePath],
  );

  const source = useMemo(
    () =>
      new XYZ({
        url: sourceUrl,
        maxZoom: mapSize.maxZoom,
        minZoom: mapSize.minZoom,
        tileSize: mapSize.tileSize,
        wrapX: OPTIONS.wrapXInTileLayer,
      }),
    [sourceUrl, mapSize.maxZoom, mapSize.minZoom, mapSize.tileSize],
  );

  const tileLayer = useMemo(
    (): TileLayer<XYZ> =>
      new TileLayer({
        visible: true,
        source,
      }),
    [source],
  );

  useEffect(() => {
    if (!mapInstance) {
      return;
    }

    mapInstance.setLayers([tileLayer]);
  }, [tileLayer, mapInstance]);

  return [tileLayer];
};
