import { OPTIONS } from '@/constants/map';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { mapDataSizeSelector } from '@/redux/map/map.selectors';
import { View } from 'ol';
import { useEffect } from 'react';
import { useSelector } from 'react-redux';
import { useDebouncedCallback } from 'use-debounce';
import { onMapPositionChange } from './onMapPositionChange';

interface UseOlMapListenersInput {
  view: View;
}

export const useOlMapListeners = ({ view }: UseOlMapListenersInput): void => {
  const mapSize = useSelector(mapDataSizeSelector);
  const dispatch = useAppDispatch();

  const handleChangeCenter = useDebouncedCallback(
    onMapPositionChange(mapSize, dispatch),
    OPTIONS.queryPersistTime,
    { leading: false },
  );

  useEffect(() => {
    view.on('change:center', handleChangeCenter);
  }, [view, handleChangeCenter]);
};
