import { ActionReducerMapBuilder } from '@reduxjs/toolkit';
import { DEFAULT_ERROR } from '@/constants/errors';
import { BioEntityContentsState } from './bioEntity.types';
import { getBioEntity, getMultiBioEntity } from './bioEntity.thunks';

export const getBioEntityContentsReducer = (
  builder: ActionReducerMapBuilder<BioEntityContentsState>,
): void => {
  builder.addCase(getBioEntity.pending, (state, action) => {
    state.data.push({
      searchQueryElement: action.meta.arg.searchQuery,
      data: undefined,
      loading: 'pending',
      error: DEFAULT_ERROR,
    });
  });
  builder.addCase(getBioEntity.fulfilled, (state, action) => {
    const bioEntities = state.data.find(
      bioEntity => bioEntity.searchQueryElement === action.meta.arg.searchQuery,
    );
    if (bioEntities) {
      bioEntities.data = action.payload;
      bioEntities.loading = 'succeeded';
    }
  });
  builder.addCase(getBioEntity.rejected, (state, action) => {
    const chemicals = state.data.find(
      chemical => chemical.searchQueryElement === action.meta.arg.searchQuery,
    );
    if (chemicals) {
      chemicals.loading = 'failed';
      // TODO: error management to be discussed in the team
    }
  });
};

export const getMultiBioEntityContentsReducer = (
  builder: ActionReducerMapBuilder<BioEntityContentsState>,
): void => {
  builder.addCase(getMultiBioEntity.pending, state => {
    state.data = [];
    state.loading = 'pending';
  });
  builder.addCase(getMultiBioEntity.fulfilled, state => {
    state.loading = 'succeeded';
  });
  builder.addCase(getMultiBioEntity.rejected, state => {
    state.loading = 'failed';
    // TODO: error management to be discussed in the team
  });
};
