import { chemicalsFixture } from '@/models/fixtures/chemicalsFixture';
import { apiPath } from '@/redux/apiPath';
import {
  ToolkitStoreWithSingleSlice,
  createStoreInstanceUsingSliceReducer,
} from '@/utils/createStoreInstanceUsingSliceReducer';
import { mockNetworkResponse } from '@/utils/mockNetworkResponse';
import { HttpStatusCode } from 'axios';
import chemicalsReducer from './chemicals.slice';
import { getChemicals } from './chemicals.thunks';
import { ChemicalsState } from './chemicals.types';

const mockedAxiosClient = mockNetworkResponse();
const SEARCH_QUERY = 'Corticosterone';

describe('chemicals thunks', () => {
  let store = {} as ToolkitStoreWithSingleSlice<ChemicalsState>;
  beforeEach(() => {
    store = createStoreInstanceUsingSliceReducer('chemicals', chemicalsReducer);
  });
  describe('getChemiclas', () => {
    it('should return data when data response from API is valid', async () => {
      mockedAxiosClient
        .onGet(apiPath.getChemicalsStringWithQuery(SEARCH_QUERY))
        .reply(HttpStatusCode.Ok, chemicalsFixture);

      const { payload } = await store.dispatch(getChemicals(SEARCH_QUERY));
      expect(payload).toEqual(chemicalsFixture);
    });
    it('should return undefined when data response from API is not valid ', async () => {
      mockedAxiosClient
        .onGet(apiPath.getChemicalsStringWithQuery(SEARCH_QUERY))
        .reply(HttpStatusCode.Ok, { randomProperty: 'randomValue' });

      const { payload } = await store.dispatch(getChemicals(SEARCH_QUERY));
      expect(payload).toEqual(undefined);
    });
  });
});
