import { mirnasFixture } from '@/models/fixtures/mirnasFixture';
import { mockNetworkResponse } from '@/utils/mockNetworkResponse';
import {
  ToolkitStoreWithSingleSlice,
  createStoreInstanceUsingSliceReducer,
} from '@/utils/createStoreInstanceUsingSliceReducer';
import { HttpStatusCode } from 'axios';
import { apiPath } from '@/redux/apiPath';
import { getMirnas } from './mirnas.thunks';
import mirnasReducer from './mirnas.slice';
import { MirnasState } from './mirnas.types';

const mockedAxiosClient = mockNetworkResponse();
const SEARCH_QUERY = 'hsa-miR-302b-3p';

describe('mirnas thunks', () => {
  let store = {} as ToolkitStoreWithSingleSlice<MirnasState>;
  beforeEach(() => {
    store = createStoreInstanceUsingSliceReducer('mirnas', mirnasReducer);
  });
  describe('getMirnas', () => {
    it('should return data when data response from API is valid', async () => {
      mockedAxiosClient
        .onGet(apiPath.getMirnasStringWithQuery(SEARCH_QUERY))
        .reply(HttpStatusCode.Ok, mirnasFixture);

      const { payload } = await store.dispatch(getMirnas(SEARCH_QUERY));
      expect(payload).toEqual(mirnasFixture);
    });
    it('should return undefined when data response from API is not valid ', async () => {
      mockedAxiosClient
        .onGet(apiPath.getMirnasStringWithQuery(SEARCH_QUERY))
        .reply(HttpStatusCode.Ok, { randomProperty: 'randomValue' });

      const { payload } = await store.dispatch(getMirnas(SEARCH_QUERY));
      expect(payload).toEqual(undefined);
    });
  });
});
