/* eslint-disable no-magic-numbers */ /* due to math nature of this algo */
import { VALID_MAP_SIZE_SCHEMA } from '@/constants/map';
import { MapSize } from '@/redux/map/map.types';
import { Point } from '@/types/map';

interface GetPointOffsetResults extends Point {
  pointOrigin: Point;
  pointShifted: Point;
  zoomFactor: number;
}

export const getPointOffset = (point: Point, mapSize: MapSize): GetPointOffsetResults => {
  // parse throws error if map size may lead to invalid results
  VALID_MAP_SIZE_SCHEMA.parse(mapSize);

  const longestSide = Math.max(mapSize.width, mapSize.height);
  const minZoomShifted = mapSize.minZoom * 2 ** mapSize.minZoom;
  const zoomFactor = longestSide / (mapSize.tileSize / minZoomShifted);

  const pointOrigin: Point = {
    x: mapSize.tileSize / 2,
    y: mapSize.tileSize / 2,
  };

  const pointShifted: Point = {
    x: point.x / zoomFactor,
    y: point.y / zoomFactor,
  };

  return {
    x: pointShifted.x - pointOrigin.x,
    y: pointShifted.y - pointOrigin.y,
    pointOrigin,
    pointShifted,
    zoomFactor,
  };
};
