/* eslint-disable no-magic-numbers */
import { LatLng, Point } from '@/types/map';
import { Options, latLngToPoint } from './latLngToPoint';

describe('latLngToPoint - util', () => {
  describe('on map with default tileSize = 256', () => {
    const mapSize = {
      width: 5170,
      height: 1535.1097689075634,
      tileSize: 256,
      minZoom: 2,
      maxZoom: 7,
    };

    const cases: [LatLng, Point, Options][] = [
      [
        [84.480312233386, -159.90463877126223],
        {
          x: 2308.7337233905396,
          y: 719.5731221907884,
        },
        {
          rounded: false,
        },
      ],
      [
        [84.20644283660516, -153.43406886300772],
        {
          x: 3052,
          y: 1039,
        },
        {
          rounded: true,
        },
      ],
    ];

    it.each(cases)('should return valid point', (latLng, point, options) =>
      expect(latLngToPoint(latLng, mapSize, options)).toStrictEqual(point),
    );
  });

  describe('on map with non-default tileSize = 128', () => {
    const mapSize = {
      width: 26779.25,
      height: 13503,
      tileSize: 256,
      minZoom: 2,
      maxZoom: 9,
    };

    const cases: [LatLng, Point, Options][] = [
      [
        [843.480312233386, -84.90463877126223],
        {
          x: 56590.721159659464,
          y: 66154.2246606772,
        },
        {
          rounded: false,
        },
      ],
      [
        [32443.4536345435, -5546654.543645645],
        {
          x: -3300676187,
          y: 78350,
        },
        {
          rounded: true,
        },
      ],
    ];

    it.each(cases)('should return valid point', (latLng, point, options) =>
      expect(latLngToPoint(latLng, mapSize, options)).toStrictEqual(point),
    );
  });
});
